#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 linear
version:              1.23.3
visibility:           public
id:                   linear-1.23.3-DfsAGXcwhWs3dWP71ZrXZr
key:                  linear-1.23.3-DfsAGXcwhWs3dWP71ZrXZr
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  e5efbd3f4072fa2f8cfeeb9b087500b6
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.6.6/site-local/linear-1.23.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/linear-1.23.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/linear-1.23.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.23.3-DfsAGXcwhWs3dWP71ZrXZr
depends:
    adjunctions-4.4.4-Cg0JLwPxse01lSKuEZWwy8 base-4.18.2.1
    base-orphans-0.9.4-F93g79l8c15JRU0CelkMYu binary-0.8.9.1
    bytes-0.17.5-AhLl0Nd5l2GE4c5EwEd3CP
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK containers-0.6.7
    deepseq-1.4.8.1 distributive-0.6.3-7aYPGPHhVXd4FJqU4bakPh
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    indexed-traversable-0.1.5-joXpPaCxYw3UYRlFaP36
    lens-5.3.5-ApAD4D8hy7K2t3Q7L3bBvG
    random-1.2.1.3-JQ5HMleih0QHEX58PgSIMQ
    reflection-2.1.9-FYkipMoONr1Hl4pQkAUzaw
    semigroupoids-6.0.2-6G0WEN9F3JRKQ3lXmqO9p6
    template-haskell-2.20.0.0 transformers-0.6.1.0
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

